@@ -1,4 +1,4 @@
-unless Fixnum.method_defined? :div
+unless Integer.method_defined?(:div) || Fixnum.method_defined?(:div)
   class Fixnum
     def div(n)
       (self / n).to_i
