@@ -1,5 +1,5 @@
 unless String.respond_to? :try_convert
-  require 'backports/tools'
+  require 'backports/tools/arguments'
 
   def String.try_convert(x)
     Backports.try_convert(x, String, :to_str)
