@@ -1,4 +1,6 @@
 unless Range.method_defined? :bsearch
+  require 'backports/tools/float_integer_conversion'
+
   class Range
     def bsearch
       return to_enum(:bsearch) unless block_given?
@@ -12,13 +14,9 @@ unless Range.method_defined? :bsearch
       if from.is_a?(Integer) && to.is_a?(Integer)
         convert = Proc.new{ midpoint }
       else
-        map = Proc.new do |pk, unpk, nb|
-          result, = [nb.abs].pack(pk).unpack(unpk)
-          nb < 0 ? -result : result
-        end
-        from = map['D', 'q', to.to_f]
-        to   = map['D', 'q', to.to_f]
-        convert = Proc.new{ map['q', 'D', midpoint] }
+        from = Backports.float_to_integer(from.to_f)
+        to   = Backports.float_to_integer(to.to_f)
+        convert = Proc.new{ Backport.integer_to_float(midpoint) }
       end
       to -= 1 if exclude_end?
       satisfied = nil
